@@ -2142,4 +2142,24 @@ export default function waitUntil(callback, options = {}) {
             p.parse_expr()
         });
     }
+
+    #[test]
+    #[should_panic(expected = "Trailing comma is disallowed inside import(...) arguments")]
+    fn error_for_trailing_commma_inside_dynamic_import() {
+        let src = "import('foo',)";
+        test_parser(src, Syntax::Es(Default::default()), |p| p.parse_expr());
+    }
+
+    #[test]
+    fn no_error_for_trailing_commma_inside_dynamic_import_with_import_assertions() {
+        let src = "import('foo',)";
+        test_parser(
+            src,
+            Syntax::Es(EsConfig {
+                import_assertions: true,
+                ..Default::default()
+            }),
+            |p| p.parse_expr(),
+        );
+    }
 }
